@@ -106,7 +106,7 @@
 #include <MailTransport/TransportManager>
 
 #include <Libkdepim/ProgressManager>
-#include <Libkdepim/BroadcastStatus>
+#include <PimCommon/BroadcastStatus>
 #ifndef QT_NO_CURSOR
 #include <Libkdepim/KCursorSaver>
 #endif
@@ -117,7 +117,6 @@
 
 #include <KEmailAddress>
 #include <KFileWidget>
-#include <KJobWidgets>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KRecentDirs>
@@ -258,7 +257,7 @@ void KMCommand::start()
     }
 
     // Special case of operating on message that isn't in a folder
-    const Akonadi::Item mb = mMsgList.first();
+    const Akonadi::Item mb = mMsgList.constFirst();
     if ((mMsgList.count() == 1) && MessageComposer::Util::isStandaloneMessage(mb)) {
         mRetrievedMsgs.append(mMsgList.takeFirst());
         Q_EMIT messagesTransfered(OK);
@@ -446,11 +445,12 @@ KMCommand::Result KMMailtoReplyCommand::execute()
         return Failed;
     }
     CreateReplyMessageJobSettings settings;
-    settings.mItem = item;
-    settings.mMsg = msg;
-    settings.mSelection = mSelection;
-    settings.mUrl = mUrl;
-    settings.m_replyStrategy = MessageComposer::ReplyNone;
+    settings.item = item;
+    settings.msg = msg;
+    settings.selection = mSelection;
+    settings.url = mUrl;
+    settings.replyStrategy = MessageComposer::ReplyNone;
+    settings.replyAsHtml = mReplyAsHtml;
 
     CreateReplyMessageJob *job = new CreateReplyMessageJob;
     job->setSettings(settings);
@@ -459,6 +459,16 @@ KMCommand::Result KMMailtoReplyCommand::execute()
     return OK;
 }
 
+bool KMMailtoReplyCommand::replyAsHtml() const
+{
+    return mReplyAsHtml;
+}
+
+void KMMailtoReplyCommand::setReplyAsHtml(bool replyAsHtml)
+{
+    mReplyAsHtml = replyAsHtml;
+}
+
 KMMailtoForwardCommand::KMMailtoForwardCommand(QWidget *parent, const QUrl &url, const Akonadi::Item &msg)
     : KMCommand(parent, msg)
     , mUrl(url)
@@ -476,9 +486,9 @@ KMCommand::Result KMMailtoForwardCommand::execute()
         return Failed;
     }
     CreateForwardMessageJobSettings settings;
-    settings.mItem = item;
-    settings.mMsg = msg;
-    settings.mUrl = mUrl;
+    settings.item = item;
+    settings.msg = msg;
+    settings.url = mUrl;
 
     CreateForwardMessageJob *job = new CreateForwardMessageJob;
     job->setSettings(settings);
@@ -852,12 +862,14 @@ KMCommand::Result KMReplyCommand::execute()
     }
 
     CreateReplyMessageJobSettings settings;
-    settings.mItem = item;
-    settings.mMsg = msg;
-    settings.mSelection = mSelection;
-    settings.m_replyStrategy = m_replyStrategy;
-    settings.mTemplate = mTemplate;
-    settings.mNoQuote = mNoQuote;
+    settings.item = item;
+    settings.msg = msg;
+    settings.selection = mSelection;
+    settings.replyStrategy = m_replyStrategy;
+    settings.templateStr = mTemplate;
+    settings.noQuote = mNoQuote;
+    settings.replyAsHtml = mReplyAsHtml;
+    qDebug() << " settings " << mReplyAsHtml;
 
     CreateReplyMessageJob *job = new CreateReplyMessageJob;
     job->setSettings(settings);
@@ -866,6 +878,17 @@ KMCommand::Result KMReplyCommand::execute()
     return OK;
 }
 
+bool KMReplyCommand::replyAsHtml() const
+{
+    return mReplyAsHtml;
+}
+
+void KMReplyCommand::setReplyAsHtml(bool replyAsHtml)
+{
+    qDebug() << " void KMReplyCommand::setReplyAsHtml(bool replyAsHtml)"<<replyAsHtml;
+    mReplyAsHtml = replyAsHtml;
+}
+
 KMForwardCommand::KMForwardCommand(QWidget *parent, const Akonadi::Item::List &msgList, uint identity, const QString &templateName, const QString &selection)
     : KMCommand(parent, msgList)
     , mIdentity(identity)
@@ -897,11 +920,11 @@ KMCommand::Result KMForwardCommand::createComposer(const Akonadi::Item &item)
 #endif
 
     CreateForwardMessageJobSettings settings;
-    settings.mItem = item;
-    settings.mMsg = msg;
-    settings.mIdentity = mIdentity;
-    settings.mTemplate = mTemplate;
-    settings.mSelection = mSelection;
+    settings.item = item;
+    settings.msg = msg;
+    settings.identity = mIdentity;
+    settings.templateStr = mTemplate;
+    settings.selection = mSelection;
 
     CreateForwardMessageJob *job = new CreateForwardMessageJob;
     job->setSettings(settings);
@@ -1176,7 +1199,7 @@ KMCommand::Result KMSetStatusCommand::execute()
             }
         }
         Akonadi::Item item(it);
-        const Akonadi::Item::Flag flag = *(mStatus.statusFlags().begin());
+        const Akonadi::Item::Flag flag = *(mStatus.statusFlags().constBegin());
         if (mInvertMark) {
             if (item.hasFlag(flag)) {
                 item.clearFlag(flag);
@@ -1324,7 +1347,7 @@ KMCommand::Result KMFilterActionCommand::execute()
             progressItem->updateProgress();
             const QString statusMsg = i18n("Filtering message %1 of %2",
                                            msgCount, msgCountToFilter);
-            KPIM::BroadcastStatus::instance()->setStatusMsg(statusMsg);
+            PimCommon::BroadcastStatus::instance()->setStatusMsg(statusMsg);
             qApp->processEvents(QEventLoop::ExcludeUserInputEvents, 50);
         }
 
